package com.zanxiang.sdk.service.Impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zanxiang.common.exception.BaseException;
import com.zanxiang.module.util.bean.BeanUtil;
import com.zanxiang.mybatis.entity.GameApplet;
import com.zanxiang.mybatis.mapper.GameAppletMapper;
import com.zanxiang.sdk.domain.dto.GameAppletDTO;
import com.zanxiang.sdk.domain.params.UserData;
import com.zanxiang.sdk.domain.vo.GameAppletVO;
import com.zanxiang.sdk.service.GameAppletService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

/**
 * @author : lingfeng
 * @time : 2022-07-08
 * @description : 微信小游戏
 */
@Slf4j
@Service
public class GameAppletServiceImpl extends ServiceImpl<GameAppletMapper, GameApplet> implements GameAppletService {

    /**
     * 通过游戏id和app id
     *
     * @param gameId 游戏id
     * @return {@link GameAppletDTO}
     */
    @Override
    public GameAppletDTO getByGameId(Long gameId) {
        GameApplet gameApplet = super.getOne(new LambdaQueryWrapper<GameApplet>()
                .eq(GameApplet::getGameId, gameId));
        if (gameApplet == null) {
            throw new BaseException("参数错误, 游戏小程序信息不存在");
        }
        return BeanUtil.copy(gameApplet, GameAppletDTO.class);
    }

    /**
     * 微信小游戏初始化获取信息
     *
     * @param userData : 用户信息
     * @return {@link GameAppletVO}
     */
    @Override
    public GameAppletVO gameAppletInit(UserData userData) {
        GameApplet gameApplet = super.getOne(new LambdaQueryWrapper<GameApplet>()
                .eq(GameApplet::getGameId, userData.getGameId()));
        if (gameApplet == null) {
            throw new BaseException("参数错误, 游戏小程序信息不存在");
        }
        return BeanUtil.copy(gameApplet, GameAppletVO.class);
    }
}
